import { Header } from '@/views/Service'
import { fetchServices, fetchService } from '@/lib/contentful'

import { documentToHtmlString } from '@contentful/rich-text-html-renderer'

export default function ({ service }) {
  return (
    <div className={'mx-auto max-w-screen-xl'}>
      <Header
        contact={{
          name: service.contactInformation.fields.name,
          mailTo: service.contactInformation.fields.eMail,
        }}
        img={{
          src: service.logo.fields.file.url,
          alt: service.logo.fields.name,
        }}
        title={service.name}
        shortDescription={documentToHtmlString(service.shortDescription)}
        developer={{
          name: service.developer.fields.name,
          link: service.developer.fields.link,
        }}
        status={service.status}
        documentationURL={service.documentationURL}
        sourceURL={service.sourcecodeURL}
      />
      <div
        dangerouslySetInnerHTML={{
          __html: documentToHtmlString(service.shortDescription),
        }}
      />
    </div>
  )
}

export async function getStaticProps({ params }) {
  const service = await fetchService(params.serviceName)

    console.log(service.fields)

  return {
    props: {
      service: service.fields,
    },
  }
}

export async function getStaticPaths() {
  const servicePaths = (await fetchServices()).map((service) => {
    return { params: { serviceName: service.fields.slug } }
  })

  return {
    paths: servicePaths,
    fallback: false,
  }
}
